from ..generic_extractors import *
from bs4 import BeautifulSoup

# A class dedicated to get events from La Cour des 3 Coquins
# URL: https://billetterie-c3c.clermont-ferrand.fr//
class CExtractor(TwoStepsExtractor):
    nom_lieu = "La Cour des 3 Coquins"

    def category_c3c2agenda(self, category):
        if not category:
            return None
        mapping = {"Théâtre": "Théâtre", "Concert": "Concert", "Projection": "Cinéma"}
        if category in mapping:
            return mapping[category]
        else:
            return None

    def build_event_url_list(self, content):
        soup = BeautifulSoup(content, "html.parser")

        events = soup.select("div.fiche-info")

        for e in events:
            e_url = e.select_one("a.btn.lien_savoir_plus")["href"]
            if e_url != "":
                e_url = self.url + "/" + e_url
                self.add_event_url(e_url)

    def add_event_from_content(
        self,
        event_content,
        event_url,
        url_human=None,
        default_values=None,
        published=False,
    ):
        soup = BeautifulSoup(event_content, "html.parser")

        title = soup.select_one("h1")
        if title:
            title = title.text

        image = soup.select_one("#media .swiper-slide img")
        if image:
            image = image["src"]
        else:
            image = None
            
        description = soup.select_one(".presentation")
        duree = soup.select_one("#criteres .DUREE-V .valeur-critere li")
        if duree is not None:
            duree = self.parse_french_time(duree.text)

        location = self.nom_lieu
        tags = []
        for t in soup.select(".sous-titre span"):
            classes = t.get("class")
            if classes and len(classes) > 0:
                if classes[0].startswith("LIEU-"):
                    location = t.text
                elif classes[0].startswith("THEMATIQUE-"):
                    tag = self.category_c3c2agenda(t.text)
                    if tag is not None:
                        tags.append(tag)

        # TODO: parser les dates, récupérer les heures ()
        dates = [self.parse_french_date(o.get("value")) for o in soup.select("select.datedleb_resa option")]
    
            

        print("EVENT ", event_url)
        print("- ", title)
        print("- ", image)
        print("- ", len(description))
        print("- ", duree)
        print("- ", location)
        print("- ", tags)
        print("- ", dates)

        return


        url_human = event_url

        self.add_event_with_props(
            event_url,
            None,
            None,
            start_day,
            location,
            description,
            tags,
            recurrences=None,
            uuids=[event_url],
            url_human=url_human,
            start_time=start_time,
            end_day=end_day,
            end_time=end_time,
            published=published,
            image=image,
        )
